/*
# ---------------------------------------------------------------------
#
# Copyright (c) CREATIS (Centre de Recherche en Acquisition et Traitement de l'Image 
#                        pour la Santé)
# Authors : Eduardo Davila, Frederic Cervenansky, Claire Mouton
#
#  This software is governed by the CeCILL-B license under French law and 
#  abiding by the rules of distribution of free software. You can  use, 
#  modify and/ or redistribute the software under the terms of the CeCILL-B 
#  license as circulated by CEA, CNRS and INRIA at the following URL 
#  http://www.cecill.info/licences/Licence_CeCILL-B_V1-en.html 
#  or in the file LICENSE.txt.
#
#  As a counterpart to the access to the source code and  rights to copy,
#  modify and redistribute granted by the license, users are provided only
#  with a limited warranty  and the software's author,  the holder of the
#  economic rights,  and the successive licensors  have only  limited
#  liability. 
#
#  The fact that you are presently reading this means that you have had
#  knowledge of the CeCILL-B license and that you accept its terms.
# ------------------------------------------------------------------------  
*/

/*=========================================================================                                                                               
Program:   bbtk
Module:    $RCSfile$
Language:  C++
Date:      $Date$
Version:   $Revision$
=========================================================================*/

/* ---------------------------------------------------------------------

* Copyright (c) CREATIS-LRMN (Centre de Recherche en Imagerie Medicale)
* Authors : Eduardo Davila, Laurent Guigues, Jean-Pierre Roux
*
*  This software is governed by the CeCILL-B license under French law and 
*  abiding by the rules of distribution of free software. You can  use, 
*  modify and/ or redistribute the software under the terms of the CeCILL-B 
*  license as circulated by CEA, CNRS and INRIA at the following URL 
*  http://www.cecill.info/licences/Licence_CeCILL-B_V1-en.html 
*  or in the file LICENSE.txt.
*
*  As a counterpart to the access to the source code and  rights to copy,
*  modify and redistribute granted by the license, users are provided only
*  with a limited warranty  and the software's author,  the holder of the
*  economic rights,  and the successive licensors  have only  limited
*  liability. 
*
*  The fact that you are presently reading this means that you have had
*  knowledge of the CeCILL-B license and that you accept its terms.
* ------------------------------------------------------------------------ */                                                                         

/**
*  \file 
*  \brief Class bbtk::GObjectModel 
*/


#include "GObjectModel.h"

namespace bbtk
{


	//=========================================================================
	GObjectModel::GObjectModel()
	{

		_xInic = 0;
		_yInic = 0;
		_zInic = GPOSITION_Z;
		_xFin = 0;
		_yFin = 0;
		_zFin = GPOSITION_Z;
	}

	//=========================================================================
	GObjectModel::~GObjectModel()
	{
	}
	//=========================================================================

	void GObjectModel::getInicPoint(double& x, double& y, double& z)
	{
		x = _xInic;
		y = _yInic;
		z = _zInic;
	}
	//=========================================================================

	void GObjectModel::getFinalPoint(double& x, double& y, double& z)
	{
		x = _xFin;
		y = _yFin;
		z = _zFin;
	}
	//=========================================================================

	void GObjectModel::getCenter(double& x, double& y, double& z)
	{
		x = (_xInic+_xFin)/2;
		y = (_yInic+_yFin)/2;
		z = (_zInic+_zFin)/2;
	}
	//=========================================================================

	void GObjectModel::setInicPoint(double& x, double& y, double& z)
	{
		_xInic = x;
		_yInic = y;
		_zInic = z;
		
	}
	//=========================================================================

	void GObjectModel::setFinalPoint(double& x, double& y, double& z)
	{
		_xFin = x;
		_yFin = y;
		_zFin = z;
	}
	//=========================================================================

	void GObjectModel::setGObjectType(int gObjectType)
	{
		_gObjectType = gObjectType;
	}

	//=========================================================================

	int GObjectModel::getGObjectType()
	{
		return _gObjectType;
	}

	//=========================================================================

	bool GObjectModel::isPointInside(double x,double y, double z)//virtual
	{
		if(x>=_xInic && x<=_xFin && y<=_yInic && y>=_yFin)
		{
			return true;
		}
		else
		{
			return false;
		}
	}

	//=========================================================================

	void GObjectModel::move(double xx,double yy,double zz)//virtual
	{
		setInicPoint(xx,yy,zz);
	}

	//=========================================================================

	std::string GObjectModel::getBBTKType()
	{
		return _bbtkType; 
	}

	//=========================================================================

	void GObjectModel::setBBTKType(std::string obtype)
	{
		_bbtkType = obtype;
	}

	//=========================================================================
		
	std::string GObjectModel::getBBTKName()
	{
		return _bbtkName;
	}

	//=========================================================================

	void GObjectModel::setBBTKName(std::string obname)
	{
		_bbtkName = obname;
	}

	//=========================================================================
	
	std::string GObjectModel::getBBTKDescription()
	{
		return _bbtkDescription;
	}
	
	//=========================================================================
	
	void GObjectModel::setBBTKDescription(std::string obdescription)
	{
		_bbtkDescription = obdescription;
	}
	
	//=========================================================================

	std::string GObjectModel::getStatusText()//virtual
	{
		std::string virt = "";
		return virt;
	}

	//=========================================================================

	int GObjectModel::getObjectId()
	{
		return _objectId;
	}

	//=========================================================================
	
	void GObjectModel::setObjectId(int id)
	{
		_objectId=id;
	}

	//=========================================================================

	void GObjectModel::save(std::string &content)
	{
		//virtual
	}
	
	//=========================================================================

}  // EO namespace bbtk

// EOF

